﻿using System;

namespace FactorialCalculator
{
    public class Program
    {
        private const int MaxNumber = 31; // This constant defines the maximum supported number for factorial calculation
        public static int CalculateFactorial(int number)
        {
            if (number < 0 || number > MaxNumber)
            {
                throw new ArgumentOutOfRangeException("number", $"Number must be between 0 and {MaxNumber}.");
            }

            int factorial = 1;
            for (int i = 2; i <= number; i++)
            {
                factorial *= i;
            }
            return factorial;
        }
        static void Main(string[] args)
        {
            Console.WriteLine("Welcome to the Factorial Calculator!");
            Console.WriteLine($"This program can calculate factorials for numbers between 0 and {MaxNumber}.");

            while (true)
            {
                Console.WriteLine("Enter a non-negative number: ");
                string input = Console.ReadLine();

                int number;
                if (!int.TryParse(input, out number))
                {
                    Console.WriteLine("Invalid input. Please enter a number.");
                    continue;
                }

                try
                {
                    int factorial = CalculateFactorial(number);
                    Console.WriteLine($"The factorial of {number} is: {factorial}");
                }
                catch (ArgumentOutOfRangeException ex)
                {
                    Console.WriteLine(ex.Message);
                }

                Console.WriteLine("Do you want to calculate another factorial? (y/n)");
                string answer = Console.ReadLine();
                if (answer.ToLower() != "y")
                {
                    break;
                }
            }

            Console.WriteLine("Thank you for using the Factorial Calculator. Press any key to close the console");
            Console.ReadKey();
        }
    }
}